function [H2, h, c] = bandwidth2(x)
% PURPOSE: compute the squared bandwidth.
% ----------------------------------------------------
% USAGE:   [H2, h, c] = bandwidth2(x)
% where:   x = matrix d times n of n d-dimensional vectors
% -----------------------------------------------------
% RETURNS: H2 = FSRMCD-covariance matrix times the correction factor
%          h  = scalar bandwidth
%          c  = FSRMCD mean vectors
% -----------------------------------------------------    

    [d, n] = size(x);

    [~, REW] = irmcd(x', 'msg', 0, 'betathresh', 1, 'conflev', (1 - 0.01)^(1/n), 'conflevrew', 0.975, ...
                   'nsamp', 500, 'refsteps', 20, 'reftol', 1e-10, 'refstepsbestr', 20);
    
    H2 = REW.cor;
    c  = (REW.loc)';
               
    P = ...
    [0.804471647090726 9521.38393889947 -2.76470289047665;
     0.683523222997110 23.5686641411822 -0.871799371301984;
     0.753228747836924 37.5118501452857 -0.983370560315213;
     1.36274340436391 8096.03030198624 -2.05556899568161;
     1.79214101436798 869.695041540100 -1.32226624500360];     

    D = [1 3 5 10 15];
    
    F = @(c, n) c(1) + c(2)*n.^(c(3));
    
    ind = find(D == d);
    if (ind > 0)
        cnd = F(P(ind, :), n);
    else
        if (d > max(d))
            cnd = F(P(end, :), n);
        else
            ind = find(sort([D d], 'ascend') == d);
            s1 = F(P(ind - 1, :), n);
            s2 = F(P(ind    , :), n);  
            cnd = ((d - D(ind - 1))*s2 + (D(ind) - d)*s1)/(D(ind) - D(ind - 1));
        end
    end
    
    % The bandwidth is given as h*(H2)^(1/2)
    H2  = cnd*H2;
    h = (4/(4 + d))^(1/(d + 6))*n^(-1/(d + 6));
    
    function sS = sqrtm(S)
        [V, E] = eig(S);
        sS = V*sqrt(E)*inv(V);
    end
 end