function theta = symmetry_threshold(alpha, d, n)
% PURPOSE: Compute symmetry threshold
% ----------------------------------------------------
% USAGE:   theta = symmetry_threshold(alpha, d, n)
% where:   alpha = tail parameter since (1 - alpha)-th level set of chi2(d)
%                  is taken
%          d = dimension
%          n = sample size
% -----------------------------------------------------
% RETURNS: theta = symmetry threshold based on the asymptotical 1.1-sigma
%                  interval
% -----------------------------------------------------    

    chi2 = chi2inv(1 - alpha, d);                            
    h = (4/(4 + d))^(1/(d + 6))*n^(-1/(d + 6));
    
    phi  = (2*pi)^(-d/2)*exp(-chi2/2);
    
    bias = (1/2)*h^2*phi*(chi2 - d);                     
    var  = 2^(-d)*pi^(-d/2)*phi/(n*h^d);
                        
    k = 1;
    theta = min(max((phi + bias - k*sqrt(var))/(phi + bias + k*sqrt(var)), 0), 1);
end